@@ -1,12 +1,9 @@
 package Net::HTTP::NB;
-
+$Net::HTTP::NB::VERSION = '6.11';
 use strict;
-use vars qw($VERSION @ISA);
+use warnings;
 
-$VERSION = "6.04";
-
-require Net::HTTP;
-@ISA=qw(Net::HTTP);
+use base 'Net::HTTP';
 
 sub can_read {
     return 1;
@@ -42,7 +39,7 @@ sub read_entity_body {
     ${*$self}{'httpnb_read_count'} = 0;
     ${*$self}{'httpnb_save'} = ${*$self}{'http_buf'};
     # XXX I'm not so sure this does the correct thing in case of
-    # transfer-encoding tranforms
+    # transfer-encoding transforms
     my $n = eval { $self->SUPER::read_entity_body(@_); };
     if ($@) {
 	$_[0] = "";
@@ -53,12 +50,18 @@ sub read_entity_body {
 
 1;
 
-__END__
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Net::HTTP::NB - Non-blocking HTTP client
 
+=head1 VERSION
+
+version 6.11
+
 =head1 SYNOPSIS
 
  use Net::HTTP::NB;
@@ -99,11 +102,20 @@ the value -1 is returned.
 
 L<Net::HTTP>
 
-=head1 COPYRIGHT
+=head1 AUTHOR
 
-Copyright 2001 Gisle Aas.
+Gisle Aas <gisle@activestate.com>
 
-This library is free software; you can redistribute it and/or
-modify it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001-2017 by Gisle Aas.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+
+#ABSTRACT: Non-blocking HTTP client
+
