@@ -1,12 +1,10 @@
 package Net::HTTPS;
-
+$Net::HTTPS::VERSION = '6.11';
 use strict;
-use vars qw($VERSION $SSL_SOCKET_CLASS @ISA);
-
-$VERSION = "6.09";
-$VERSION = eval $VERSION;
+use warnings;
 
 # Figure out which SSL implementation to use
+use vars qw($SSL_SOCKET_CLASS);
 if ($SSL_SOCKET_CLASS) {
     # somebody already set it
 }
@@ -43,7 +41,7 @@ else {
 
 require Net::HTTP::Methods;
 
-@ISA=($SSL_SOCKET_CLASS, 'Net::HTTP::Methods');
+our @ISA=($SSL_SOCKET_CLASS, 'Net::HTTP::Methods');
 
 sub configure {
     my($self, $cnf) = @_;
@@ -82,16 +80,24 @@ if ($SSL_SOCKET_CLASS eq "Net::SSL") {
 
 1;
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 Net::HTTPS - Low-level HTTP over SSL/TLS connection (client)
 
+=head1 VERSION
+
+version 6.11
+
 =head1 DESCRIPTION
 
 The C<Net::HTTPS> is a low-level HTTP over SSL/TLS client.  The interface is the same
-as the interface for C<Net::HTTP>, but the constructor method take additional parameters
-as accepted by L<IO::Socket::SSL>.  The C<Net::HTTPS> object isa C<IO::Socket::SSL>
-too, which make it inherit additional methods from that base class.
+as the interface for C<Net::HTTP>, but the constructor takes additional parameters
+as accepted by L<IO::Socket::SSL>.  The C<Net::HTTPS> object is an C<IO::Socket::SSL>
+too, which makes it inherit additional methods from that base class.
 
 For historical reasons this module also supports using C<Net::SSL> (from the
 Crypt-SSLeay distribution) as its SSL driver and base class.  This base is
@@ -109,3 +115,21 @@ is C<IO::Socket::SSL>.  Currently the only other supported value is C<Net::SSL>.
 =head1 SEE ALSO
 
 L<Net::HTTP>, L<IO::Socket::SSL>
+
+=head1 AUTHOR
+
+Gisle Aas <gisle@activestate.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001-2017 by Gisle Aas.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
+
+__END__
+
+#ABSTRACT: Low-level HTTP over SSL/TLS connection (client)
+
